
XEP-0402: PEP Native Bookmarks
==============================

.. module:: slixmpp.plugins.xep_0402

.. autoclass:: XEP_0402
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0402.stanza
    :members:
    :undoc-members:

